@@ -38,9 +38,9 @@ sub get_install_root {
 sub get_venv_builddir {
     my $this = shift;
     my $builddir = $this->get_builddir();
-    my $sourcepackage = $this->sourcepackage();
+    my $virtualenv_name = $ENV{DH_VIRTUALENV_INSTALL_SUFFIX} || $this->sourcepackage();
     my $prefix = $this->get_install_root();
-    return "$builddir$prefix/$sourcepackage";
+    return "$builddir$prefix/$virtualenv_name";
 }
 
 sub get_exec {
@@ -57,7 +57,7 @@ sub get_python {
 
 sub get_pip {
     my $this = shift;
-    return $this->get_exec("pip");
+    return ($this->get_exec("python"), "-m", "pip");
 }
 
 sub configure {
@@ -89,25 +89,25 @@ sub build {
         'virtualenv', @params, Cwd::abs_path($builddir));
 
     my $python = $this->get_python();
-    my $pip = $this->get_pip();
+    my @pip = $this->get_pip();
 
     if (defined $ENV{DH_UPGRADE_PIP}) {
         my $version = length $ENV{DH_UPGRADE_PIP} && '=='.$ENV{DH_UPGRADE_PIP} || '';
         $this->doit_in_sourcedir(
-            $python, $pip, 'install', '-U', 'pip' . $version);
+            @pip, 'install', '-U', 'pip' . $version);
     }
     if (defined $ENV{DH_UPGRADE_SETUPTOOLS}) {
         my $version = length $ENV{DH_UPGRADE_SETUPTOOLS} && '=='.$ENV{DH_UPGRADE_SETUPTOOLS} || '';
         $this->doit_in_sourcedir(
-            $python, $pip, 'install', '-U', 'setuptools' . $version);
+            @pip, 'install', '-U', 'setuptools' . $version);
     }
     if (defined $ENV{DH_UPGRADE_WHEEL}) {
         my $version = length $ENV{DH_UPGRADE_WHEEL} && '=='.$ENV{DH_UPGRADE_WHEEL} || '';
         $this->doit_in_sourcedir(
-            $python, $pip, 'install', '-U', 'wheel' . $version);
+            @pip, 'install', '-U', 'wheel' . $version);
     }
     $this->doit_in_sourcedir(
-        $python, $pip, 'install', '-r', $reqfile, @pipargs);
+        @pip, 'install', '-r', $reqfile, @pipargs);
 }
 
 sub test {
@@ -120,14 +120,14 @@ sub test {
 sub install {
     my $this = shift;
     my $destdir = shift;
-    my $pip = $this->get_pip();
+    my @pip = $this->get_pip();
     my $python = $this->get_python();
     my $sourcepackage = $this->sourcepackage();
     my $venv = $this->get_venv_builddir();
     my $prefix = $this->get_install_root();
 
     $this->doit_in_sourcedir(
-        $python, $pip, 'install', '.');
+        @pip, 'install', '.');
 
     # Before we copy files, let's make the symlinks in the 'usr/local'
     # relative to the build path.
@@ -145,11 +145,20 @@ sub install {
     $this->doit_in_builddir('mkdir', '-p', $destdir);
     $this->doit_in_builddir('cp', '-r', '-T', '.', $destdir);
 
-    my $new_python = "$prefix/$sourcepackage/bin/python";
+    my $new_python = undef;
+    my @binaries = undef;
+
+    if (defined $ENV{DH_VIRTUALENV_INSTALL_SUFFIX}) {
+        $new_python = "$prefix/" . $ENV{DH_VIRTUALENV_INSTALL_SUFFIX} . "/bin/python";
+        my $curdir = "$destdir$prefix" . $ENV{DH_VIRTUALENV_INSTALL_SUFFIX} . "/bin/*";
+        @binaries = glob($curdir);
+    } else {
+        $new_python = "$prefix/$sourcepackage/bin/python";
+        @binaries = <"$destdir$prefix/$sourcepackage/bin/*">;
+    }
 
     # Fix shebangs so that we use the Python in the final location
     # instead of the Python in the build directory
-    my @binaries = <"$destdir$prefix/$sourcepackage/bin/*">;
     {
         local $^I = q{};
         local @ARGV = grep { -T } @binaries;
